==> open-xchange-core_7.6.0.orig.tar.bz2: open-xchange-core-7.6.0/com.openexchange.itip.json/src/com/openexchange/ajax/itip/osgi/ITipJSONActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.itip.osgi;

import org.osgi.service.http.HttpService;

import com.openexchange.ajax.itip.ITipActionFactory;
import com.openexchange.ajax.itip.servlet.ITipJSONServlet;
import com.openexchange.calendar.itip.ITipAnalyzerService;
import com.openexchange.calendar.itip.ITipDingeMacherFactoryService;
import com.openexchange.calendar.itip.generators.ITipMailGeneratorFactory;
import com.openexchange.conversion.ConversionService;
import com.openexchange.data.conversion.ical.itip.ITipParser;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.multiple.AJAXActionServiceAdapterHandler;
import com.openexchange.multiple.MultipleHandlerFactoryService;
import com.openexchange.osgi.HousekeepingActivator;

/**
 * {@link ITipJSONActivator}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class ITipJSONActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] {
            ITipAnalyzerService.class, ITipParser.class, ConversionService.class, ITipDingeMacherFactoryService.class,
            ITipMailGeneratorFactory.class, HttpService.class, DispatcherPrefixService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        ITipActionFactory.INSTANCE = new ITipActionFactory(this);

        registerService(MultipleHandlerFactoryService.class, new AJAXActionServiceAdapterHandler(
            ITipActionFactory.INSTANCE,
            "calendar/itip"));

        getService(HttpService.class).registerServlet(getService(DispatcherPrefixService.class).getPrefix() + "calendar/itip", new ITipJSONServlet(), null, null);

        openTrackers();
    }

}

==> open-xchange-core_7.6.2.orig.tar.bz2: open-xchange-core-7.6.2/com.openexchange.itip.json/src/com/openexchange/ajax/itip/osgi/ITipJSONActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.ajax.itip.osgi;

import org.osgi.service.http.HttpService;
import org.osgi.util.tracker.ServiceTracker;

import com.openexchange.ajax.itip.ITipActionFactory;
import com.openexchange.ajax.itip.servlet.ITipJSONServlet;
import com.openexchange.calendar.itip.ITipAnalyzerService;
import com.openexchange.calendar.itip.ITipDingeMacherFactoryService;
import com.openexchange.calendar.itip.generators.ITipMailGeneratorFactory;
import com.openexchange.capabilities.CapabilityService;
import com.openexchange.conversion.ConversionService;
import com.openexchange.data.conversion.ical.itip.ITipParser;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.multiple.AJAXActionServiceAdapterHandler;
import com.openexchange.multiple.MultipleHandlerFactoryService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.osgi.RankingAwareNearRegistryServiceTracker;

/**
 * {@link ITipJSONActivator}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class ITipJSONActivator extends HousekeepingActivator {

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { ITipParser.class, ConversionService.class, ITipMailGeneratorFactory.class, HttpService.class, DispatcherPrefixService.class, ITipDingeMacherFactoryService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        RankingAwareNearRegistryServiceTracker<ITipAnalyzerService> rankingTracker = new RankingAwareNearRegistryServiceTracker<ITipAnalyzerService>(context, ITipAnalyzerService.class, 0);
        RankingAwareNearRegistryServiceTracker<ITipDingeMacherFactoryService> factoryTracker = new RankingAwareNearRegistryServiceTracker<ITipDingeMacherFactoryService>(context, ITipDingeMacherFactoryService.class, 0);
        ServiceTracker<CapabilityService, CapabilityService> capabilityTracker = track(CapabilityService.class);
        rememberTracker(rankingTracker);
        rememberTracker(factoryTracker);
        rememberTracker(capabilityTracker);
        openTrackers();
    
        ITipActionFactory.INSTANCE = new ITipActionFactory(this, rankingTracker, factoryTracker);

        registerService(MultipleHandlerFactoryService.class, new AJAXActionServiceAdapterHandler(ITipActionFactory.INSTANCE, "calendar/itip"));

        getService(HttpService.class).registerServlet(getService(DispatcherPrefixService.class).getPrefix() + "calendar/itip", new ITipJSONServlet(this), null, null);
    }

}
